@@ -29,6 +29,8 @@ const std::string SequenceSummary::codonArrayParameter[] =
 		 "TCC", "TCG", "ACA", "ACC", "ACG",
 		 "GTA", "GTC", "GTG", "TAC", "AGC"};
 
+
+
 const std::map<std::string, unsigned> SequenceSummary::aaToIndex = {{"A", 0}, {"C", 1}, {"D", 2}, {"E", 3}, {"F", 4},
 	{"G", 5}, {"H", 6}, {"I", 7}, {"K", 8}, {"L", 9}, {"M", 10}, {"N", 11}, {"P", 12}, {"Q", 13}, {"R", 14}, {"S", 15},
 	{"T", 16}, {"V", 17}, {"W", 18}, {"Y", 19}, {SequenceSummary::Ser2, 20}, {"X", 21}};
@@ -49,7 +51,14 @@ const std::map<std::string, unsigned> SequenceSummary::codonToIndexWithoutRefere
 	{"TCA", 29}, {"TCC", 30}, {"TCG", 31}, {"ACA", 32}, {"ACC", 33}, {"ACG", 34}, {"GTA", 35}, {"GTC", 36}, {"GTG", 37},
 	{"TAC", 38}, {"AGC", 39}};
 
-
+/*
+const std::map<std::string, unsigned> SequenceSummary::codonToIndexWithoutReference = {{"GCT", 0}, {"GCC", 1},
+	{"GCG", 2}, {"TGT", 3}, {"GAT", 4}, {"GAG", 5}, {"TTT", 6}, {"GGT", 7}, {"GGC", 8}, {"GGG", 9}, {"CAT", 10},
+	{"ATT", 11}, {"ATC", 12}, {"AAG", 13}, {"TTG", 14}, {"CTC", 15}, {"CTG", 16}, {"CTT", 17}, {"TTA", 18}, {"AAT", 19},
+	{"CCT", 20}, {"CCC", 21}, {"CCG", 22}, {"CAG", 23}, {"CGT", 24}, {"AGG", 25}, {"CGA", 26}, {"CGC", 27}, {"CGG", 28},
+	{"TCT", 29}, {"TCC", 30}, {"TCG", 31}, {"ACT", 32}, {"ACC", 33}, {"ACG", 34}, {"GTT", 35}, {"GTC", 36}, {"GTG", 37},
+	{"TAT", 38}, {"AGT", 39}};
+*/
 
 //------------------------------------------------//
 //---------- Constructors & Destructors ----------//
@@ -258,6 +267,43 @@ void SequenceSummary::setSumRFPCount(std::array <unsigned, 64> arg, unsigned RFP
 }
 
 
+/* getCodonSpecificSumRFPCount (by codon string) (RCPP EXPOSED VIA WRAPPER)
+ * Arguments: A three-character codon string to get the RFP value of, a number representing the RFP category to return (default 0)
+ * Returns the RFP value of the codon string for the category index specified.
+ * Note: If initSumRFPCount is not called beforehand, it is called now to return a value of 0.
+ * Wrapped by Gene::getSumRFPCountForCodon on the R-side.
+ */
+unsigned SequenceSummary::getCodonSpecificSumRFPCount(std::string codon, unsigned RFPCountColumn)
+{
+	if (sumRFPCount.size() < RFPCountColumn + 1) initSumRFPCount(RFPCountColumn + 1);
+	return sumRFPCount[RFPCountColumn][codonToIndex(codon)];
+}
+
+
+/* getCodonSpecificSumRFPCount (by codon index) (NOT EXPOSED)
+ * Arguments: A codon index to get the RFP value of, a number representing the RFP category to return (default 0)
+ * Returns the RFP value at the codon index for the category index specified.
+ * Note: If initSumRFPCount is not called beforehand, it is called now to return a value of 0.
+ */
+unsigned SequenceSummary::getCodonSpecificSumRFPCount(unsigned codonIndex, unsigned RFPCountColumn)
+{
+	if (sumRFPCount.size() < RFPCountColumn + 1) initSumRFPCount(RFPCountColumn + 1);
+    return sumRFPCount[RFPCountColumn][codonIndex];
+}
+
+
+/* setCodonSpecificSumRFPCount (NOT EXPOSED)
+ * Arguments: A codon index, the value to set the RFP value to, and a number representing the RFP category (default 0)
+ * Sets the RFP value at the codon index for the category index specified.
+ * Note: If initSumRFPCount is not called beforehand, it is called now to return initialize the vector of vectors.
+ */
+void SequenceSummary::setCodonSpecificSumRFPCount(unsigned codonIndex, unsigned value, unsigned RFPCountColumn)
+{
+    if (sumRFPCount.size() < RFPCountColumn + 1) initSumRFPCount(RFPCountColumn + 1);
+    sumRFPCount[RFPCountColumn][codonIndex] = value;
+}
+
+
 /* getPositionCodonID (NOT EXPOSED)
  * Arguments: None.
  * Returns the vector of codon IDs for each position.
@@ -278,46 +324,6 @@ void SequenceSummary::setPositionCodonID(std::vector <unsigned> arg)
 }
 
 
-/* getRFPValue (by codon string) (RCPP EXPOSED VIA WRAPPER)
- * Arguments: A three-character codon string to get the RFP value of, a number representing the RFP category to return (default 0)
- * Returns the RFP value of the codon string for the category index specified.
- * Note: If initSumRFPCount is not called beforehand, it is called now to return a value of 0.
- * Wrapped by Gene::getSumRFPCountForCodon on the R-side.
- */
-unsigned SequenceSummary::getRFPValue(std::string codon, unsigned RFPCountColumn)
-{
-	if (sumRFPCount.size() < RFPCountColumn + 1) initSumRFPCount(RFPCountColumn + 1);
-	return sumRFPCount[RFPCountColumn][codonToIndex(codon)];
-}
-
-
-/* getRFPValue (by codon index) (NOT EXPOSED)
- * Arguments: A codon index to get the RFP value of, a number representing the RFP category to return (default 0)
- * Returns the RFP value at the codon index for the category index specified.
- * Note: If initSumRFPCount is not called beforehand, it is called now to return a value of 0.
- */
-unsigned SequenceSummary::getRFPValue(unsigned codonIndex, unsigned RFPCountColumn)
-{
-	if (sumRFPCount.size() < RFPCountColumn + 1) initSumRFPCount(RFPCountColumn + 1);
-    return sumRFPCount[RFPCountColumn][codonIndex];
-}
-
-
-/* setRFPValue (NOT EXPOSED)
- * Arguments: A codon index, the value to set the RFP value to, and a number representing the RFP category (default 0)
- * Sets the RFP value at the codon index for the category index specified.
- * Note: If initSumRFPCount is not called beforehand, it is called now to return initialize the vector of vectors.
- */
-void SequenceSummary::setRFPValue(unsigned codonIndex, unsigned value, unsigned RFPCountColumn)
-{
-    if (sumRFPCount.size() < RFPCountColumn + 1) initSumRFPCount(RFPCountColumn + 1);
-    sumRFPCount[RFPCountColumn][codonIndex] = value;
-}
-
-
-
-
-
 //------------------------------------//
 //---------- Other Functions ---------//
 //------------------------------------//
